# deepl-tr
[![pytest](https://github.com/ffreemt/deepl-tr-webui/actions/workflows/routine-tests.yml/badge.svg)](https://github.com/ffreemt/deepl-tr-webui/actions)[![python](https://img.shields.io/static/v1?label=python+&message=3.8%2B&color=blue)](https://www.python.org/downloads/)[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)[![PyPI version](https://badge.fury.io/py/deepl_tr.svg)](https://badge.fury.io/py/deepl-tr)

deepl translate using deepl-fastapi and webui2

## Install it

```shell
x (not ready yet) pip install deepl-tr
# pip install git+https://github.com/ffreemt/deepl-tr-webui
# poetry add git+https://github.com/ffreemt/deepl-tr-webui
# git clone https://github.com/ffreemt/deepl-tr-webui && cd deepl-tr-webui
```

## Use it
```bash
python -m deepl_tr

# or
deepl-tr

```
